@@ -12,17 +12,16 @@ use vars qw( @ISA $VERSION );
 use Module::Install::Base;
 @ISA = qw( Module::Install::Base Module::AutoInstall );
 
-$VERSION = sprintf "%d.%02d%02d", q/0.10.04/ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%02d%02d", q/0.11.00/ =~ /(\d+)/g;
 
 # ---------------------------------------------------------------------------
 
-sub check_optional
-{
-  my $self = shift;
+sub check_optional {
+  my ($self, $module, $version, $message) = @_;
 
-	my $module = shift;
-	my $version = shift;
-	my $message = shift;
+  # Tell Module::Install to include this, since we use it.
+  $self->perl_version('5.005');
+  $self->include('Module::AutoInstall', 0);
 
   croak "check_optional requires a dependency and version such as \"Carp => 1.03\""
     unless defined $module and defined $version;
@@ -83,9 +82,8 @@ In addition, the optional MESSAGE argument will be appended to the notice.
 
 =head1 LICENSE
 
-This code is distributed under the GNU General Public License (GPL). See the
-file LICENSE in the distribution, http://www.opensource.org/gpl-license.html,
-and http://www.opensource.org/.
+This code is distributed under the GNU General Public License (GPL) Version 2.
+See the file LICENSE in the distribution for details.
 
 =head1 AUTHOR
 
